Brick Breaker
-------------

Brick Breaker is a simple game based on breaking bricks
and progressing through levels.

You can get it by downloading it directly or by typing:

.. code:: bash

    $ pip install BrickBreakerGame

After it is installed you can start it by simply typing in your terminal:

.. code:: bash

    $ brickbreaker
